@@ -331,7 +331,7 @@ public final class EConv implements EConvFlags {
             if (inBuf.bytes != null && inBuf.dataStart != inBuf.dataEnd) {
                 if (outStop - outPtr.p < inBuf.dataEnd - inBuf.dataStart) {
                     len = outStop - outPtr.p;
-                    System.arraycopy(inBuf, inBuf.dataStart, out, outPtr.p, len);
+                    System.arraycopy(inBuf.bytes, inBuf.dataStart, out, outPtr.p, len);
                     outPtr.p = outStop;
                     inBuf.dataStart += len;
                     return convertInternalResult(EConvResult.DestinationBufferFull, null);
@@ -622,10 +622,7 @@ public final class EConv implements EConvFlags {
             buf = new Buffer();
             buf.allocate(need);
         } else if (buf.bytes == null) {
-            buf.bytes = new byte[need];
-            buf.dataStart = 0;
-            buf.dataEnd = 0;
-            buf.bufEnd = need;
+            buf.allocate(need);
         } else if ((buf.bufEnd - buf.dataEnd) < need) {
             // try to compact buffer by moving data portion back to bufStart
             System.arraycopy(buf.bytes, buf.dataStart, buf.bytes, buf.bufStart, buf.dataEnd - buf.dataStart);
@@ -884,4 +881,4 @@ public final class EConv implements EConvFlags {
         }
         return true;
     }
-}
\ No newline at end of file
+}
